#!/bin/sh

# ****************************************************************************
# IBM Confidential
# OCO Source Materials
# (c) Copyright IBM Corp. 2011
#
# The source code for this program is not published or otherwise divested of 
# its trade secrets, irrespective of what has been deposited with the U.S. 
# Copyright Office.
# ****************************************************************************

# Author: Rahul Shekatkar
# Description: This script will setup the historical collection required for the ITM for
# Capacity Planner for PowerVM.  Historical Configuration is setup for 
# each attribute group that is used for the Capacity Planning component.  
# 
# In the sections below, each attribute group is documented as being Capacity Planning, 
#
# This section describes the attributes used in the script.  The values 
# provided in the script are Tivoli's recommendations, but you may make changes
# using the guidelines below.
# -c|--collectioninterval Specifies the collection interval. The acceptable 
#     inputs are 1m(inute), 5m, 15m, 30m, 1h(our), or 1d(ay). The default value 
#     is 15m(inutes).
# -l|--collectionlocation Specifies where the data collection is stored. 
#     The acceptable inputs are TEMA or TEMS. The default value is TEMA.
# -i|--warehouseinterval Specifies the warehouse interval. The acceptable inputs
#     are 15m(inutes), 30m, 1h(our), 12h, 1d(ay), or off. The default value is 
#     1d(ay).
# -d|--summarizationdetails Specifies the summarization details. If this option 
#     is not specified, summarization will be disabled. This option can be 
#     given as DH where Y=Yearly,Q=Quarterly,M=Monthly,W=Weekly,D=Daily, and 
#     H=Hourly.
# -p|--pruningdetails Specifies the pruning details. If this option is not 
#     specified, Pruning will be disabled. This option can be given as Y=1y,
#     Q=1y,M=2m,W=2m,D=1d,H=2d,R=2d where Y=Yearly,Q=Quarterly,M=Monthly,
#     W=Weekly,D=Daily,H=Hourly, and R=Detailed data.
# NOTE:  There are several tables used for Capacity Planning.   It is important
# that the capacity planning tables be configured with the same summarization 
# and pruning intervals.   This does not apply to the tables being used for
# Tivoli Common Reporting.  The tables are:
## HMC Agent 
# KPH_SERVER_DETAILS 
# KPH_SERVER_LPARS
## Unix OS Agent
# Unix_Memory 
# Machine_Information 
# AIX_LPAR 
# Network 
# Disk_Performance
## Linux OS Agent
# KLZ_LPAR 
# KLZ_VM_Stats 
# Linux_Machine_Information 
# KLZ_VM_Stats 
# KLZ_Network 
# KLZ_IO_Ext
## VIOS Agent
# KVA_PHYSICAL_MEMORY 
# KVA_TADDM 
# KVA_DISKS 
# KVA_NETWORK_ADAPTERS_RATES 
# KVA_STORAGE_MAPPINGS
# By default, these tables are being setup with 120 days of Daily summarization
# data and 30 days of Hourly summarization.

# Global function definitions 
function usage()
{
	echo "The script requires 3 parameters and has 1 optional parameter"
	echo "The syntax is:"
	echo "powervm_hist_config.sh <TEPS Hostname> <username> <password> [ITM PATH]"

}

function configure_sp_hdc()
{
		# Check whether historical collection is already setup for this attribute group
		./powervm_check_hist_config.sh $PRODUCT_CODE $ATTRIBUTE_GROUP $MSN_GROUP
		retStatus=$?
		echo "# -------------------------------------------------------------------------------------------"
		if [ $retStatus -eq 1 ];
		then
		#   Configure Summarization
			echo "Configuring Summarization & Pruning for $ATTRIBUTE_GROUP"
			$TACMD histConfigureGroups -l TEMA -i $WHINT  -d $SUMM_LEVELS -p $PRUNING_LIST -c $COLINT  -t $PRODUCT_CODE -o $ATTRIBUTE_GROUP
		fi

		if [ $retStatus -eq 2 ];
		then
		#   Configure Historical Collection
			echo "Configuring Historical Collection for $PRODUCT_CODE:$ATTRIBUTE_GROUP"
			$TACMD histcreatecollection -a $ATTRIBUTE_GROUP -t $PRODUCT_CODE -o $ATTRIBUTE_GROUP -i $WHINT -l TEMA -c $COLINT -e "historical collection for $PRODUCT_CODE agent: $ATTRIBUTE_GROUP "
			$TACMD histstartcollection  -a $ATTRIBUTE_GROUP -m "*$MSN_GROUP"
		fi

		if [ $retStatus -eq 3 ];
		then
		#   Configure both S&P and Historical Collection
			echo "configuring both S&P and Historical collection for $PRODUCT_CODE:$ATTRIBUTE_GROUP"
			$TACMD histcreatecollection -a $ATTRIBUTE_GROUP -t $PRODUCT_CODE -o $ATTRIBUTE_GROUP -i $WHINT -l TEMA -c $COLINT -e "historical collection for $PRODUCT_CODE agent: $ATTRIBUTE_GROUP "
			$TACMD histConfigureGroups -l TEMA -i $WHINT  -d $SUMM_LEVELS -p $PRUNING_LIST -c $COLINT  -t $PRODUCT_CODE -o $ATTRIBUTE_GROUP
			$TACMD histstartcollection  -a $ATTRIBUTE_GROUP -m "*$MSN_GROUP"

		fi

}

####################################################################################
export LOG_FILE=histconfig.log
# First, check to make sure that the user logs into the TEPS correctly.
if [ $# -lt 3 ]
then
	usage ;
   exit 0
else
   if [ -z $4 ]
   then
      echo ""
      echo "Using Default CANDLEHOME of /opt/IBM/ITM.  If you are using a different"
      echo "CANDLEHOME directory, please run the program again and specify the"
      echo " CANDLEHOME directory.  The command syntax is:"
      echo "powervm_hist_config.sh <TEPS Hostname> <username> <password> [ITM PATH]"
      echo " "
      export CANDLEHOME=/opt/IBM/ITM
   else
      echo "CANDLEHOME is set to " $4
      export CANDLEHOME=$4
   fi
fi

# Test whether login is successful and set timeout to 4 hours
if [ -z `$CANDLEHOME/bin/tacmd tepslogin -s $1 -u $2 -p $3 -t 240 | grep KUIC00007I | cut -f 1 -d :` ]
then
   echo "Login Failed"
   exit 0
fi

echo "Login succeeded."
echo "Beginning historical configuration.  The results will be logged to ./$LOG_FILE"

exec > ./$LOG_FILE
exec 2>&1

CURDIR=`pwd`

# ------- Global declarations 
export  TACMD=$CANDLEHOME/bin/tacmd

# Override below default collection interval as per your needs specfic to your agent attribute group.
export  COLINT=15m

# Override below default warehouse interval as per your needs specfic to your agent attribute group.
export  WHINT=15m

# Change the default Summarization levels as per your needs, current default value is set for Hourly (H), Daily (D) and Weekly (W)
# e.g. export SUMM_LEVELS=YQMWDH
export SUMM_LEVELS=MWDH

# Change default Pruning levels as per your needs
# e.g. export PRUNING_LIST="Y=2y,Q=1y,M=3m,W=3m,D=120d,H=30d,R=1d"
export PRUNING_LIST="M=3m,W=3m,D=120d,H=30d,R=1d"
#----------------------------------------------------------------------------

## HMC Agent Attribute Group configuration
#KPH_SERVER_DETAILS 
#KPH_SERVER_LPARS

COLINT=15m
WHINT=15m
#SUMM_LEVELS=WDH
#PRUNING_LIST="Y=2y,Q=1y,M=3m,W=3m,D=120d,H=30d,R=1d"

PRODUCT_CODE=kph
export MSN_GROUP="HMC_BASE_SERVERS"

ATTRIBUTE_GROUP=KPH_SERVER_DETAILS
configure_sp_hdc 

ATTRIBUTE_GROUP=KPH_SERVER_LPARS
configure_sp_hdc 

#----------------------------------------------------------------------------
## Unix OS Agent Attribute Group configuration
#Unix_Memory 
#Machine_Information 
#AIX_LPAR 
#Network 
#Disk_Performance

COLINT=15m
WHINT=15m
#SUMM_LEVELS=WDH
#PRUNING_LIST="Y=2y,Q=1y,M=3m,W=3m,D=120d,H=30d,R=1d"


PRODUCT_CODE=kux
MSN_GROUP="ALL_UNIX"
ATTRIBUTE_GROUP=Unix_Memory
configure_sp_hdc
ATTRIBUTE_GROUP=Machine_Information
configure_sp_hdc
ATTRIBUTE_GROUP=AIX_LPAR
configure_sp_hdc
ATTRIBUTE_GROUP=Network
configure_sp_hdc
ATTRIBUTE_GROUP=Disk_Performance
configure_sp_hdc

#----------------------------------------------------------------------------
## Linux OS Agent Attribute Group configuration
#KLZ_LPAR 
#KLZ_VM_Stats 
#Linux_Machine_Information 
#KLZ_VM_Stats 
#KLZ_Network 
#KLZ_IO_Ext

COLINT=15m
WHINT=15m
#SUMM_LEVELS=WDH
#PRUNING_LIST="Y=2y,Q=1y,M=3m,W=3m,D=120d,H=30d,R=1d"


PRODUCT_CODE=klz
MSN_GROUP="LINUX_SYSTEM"
ATTRIBUTE_GROUP=KLZ_LPAR
configure_sp_hdc
ATTRIBUTE_GROUP=KLZ_VM_Stats
configure_sp_hdc
ATTRIBUTE_GROUP=Linux_Machine_Information
configure_sp_hdc
ATTRIBUTE_GROUP=KLZ_VM_Stats
configure_sp_hdc
ATTRIBUTE_GROUP=KLZ_Network
configure_sp_hdc
ATTRIBUTE_GROUP=KLZ_IO_Ext
configure_sp_hdc


#----------------------------------------------------------------------------
## VIOS Agent Attribute Group configuration
#KVA_PHYSICAL_MEMORY 
#KVA_TADDM 
#KVA_DISKS 
#KVA_NETWORK_ADAPTERS_RATES 
#KVA_STORAGE_MAPPINGS

COLINT=15m
WHINT=15m
#SUMM_LEVELS=WDH
#PRUNING_LIST="Y=2y,Q=1y,M=3m,W=3m,D=120d,H=30d,R=1d"


PRODUCT_CODE=kva
MSN_GROUP="VIOS_PREMIUM"
ATTRIBUTE_GROUP=Unix_Memory
configure_sp_hdc
ATTRIBUTE_GROUP=KVA_PHYSICAL_MEMORY
configure_sp_hdc
ATTRIBUTE_GROUP=KVA_TADDM
configure_sp_hdc
ATTRIBUTE_GROUP=KVA_DISKS
configure_sp_hdc
ATTRIBUTE_GROUP=KVA_NETWORK_ADAPTERS_RATES
configure_sp_hdc
ATTRIBUTE_GROUP=KVA_STORAGE_MAPPINGS
configure_sp_hdc


echo "Historical Configuration is now complete"
exit 0
